### Links

* Docs: [palewi.re/docs/django-greeking/](https://palewi.re/docs/django-greeking/)
* Issues: [github.com/datadesk/django-greeking/issues](https://github.com/datadesk/django-greeking/issues)
* Packaging: [pypi.python.org/pypi/django-greeking](https://pypi.python.org/pypi/django-greeking)
* Testing: [github.com/datadesk/django-greeking/actions](https://github.com/datadesk/django-greeking/actions)
